@@ -308,7 +308,7 @@ class TestDriver(object):
         for_all_plugins("test_success", self, klass, method)
         finished = True
 
-        print "PASSED"
+        print >>sys.stderr, "PASSED"
         self.passed += 1
         self.tests_run += 1
       except Exception, e:
@@ -323,7 +323,7 @@ class TestDriver(object):
           for_all_plugins("test_failure", self, klass, method_name, ex, st)
           
           for line in itertools.chain(st, ex):
-            print re.sub('(' + os.getcwd() + ')(.*)", (line \\d+)', 
+            print >>sys.stderr, re.sub('(' + os.getcwd() + ')(.*)", (line \\d+)', 
                          '\\1\033[1;31m\\2\033[0;0;0m", \033[1;32m\\3\033[0;0;0m', 
                          line)
 
